
WIKIWARE_API_URL = "http://en.wikipedia.org/w/api.php"
WIKIWARE_EN_URL = "http://en.wikipedia.org/w/index.php"

WIKIWARE_QUERY_NOT_FOUND_PHRASE = [
    "refer to:",
    "does not have an article with this exact name",
]

WIKIWARE_QUERY_CONNECTION_TIMEOUT_SECONDS = 5
WIKIWARE_PARAGRAPH_MIN_CHARACTERS = 15

DEBUG = False


